@@ -1,20 +1,19 @@
 """Configuration file for the Sphinx documentation builder."""
-# pylint: disable=C0103
+
+from __future__ import annotations
+
+import datetime
 import os
 import re
 import typing as t
-from datetime import date
+from importlib.metadata import metadata
 from importlib.util import find_spec
 from pathlib import Path
 
-import sphinx_rtd_theme  # type: ignore[import]
-from sphinx.application import Sphinx
+import sphinx_rtd_theme  # type: ignore[import-untyped]
 
-
-try:
-    from importlib.metadata import metadata  # pylint: disable=ungrouped-imports
-except ModuleNotFoundError:  # pragma: py-gte-38
-    from importlib_metadata import metadata
+if t.TYPE_CHECKING:
+    from sphinx.application import Sphinx
 
 
 needs_sphinx = "3.1"  #: Minimum Sphinx version to build the docs
@@ -29,10 +28,10 @@ project = "rstcheck"
 author = "Steven Myint <git@stevenmyint.com>"
 GH_REPO_LINK = "https://github.com/rstcheck/rstcheck"
 CREATION_YEAR = 2013
-CURRENT_YEAR = f"{date.today().year}"
-copyright = (  # noqa: VNE003 # pylint: disable=W0622
+CURRENT_YEAR = f"{datetime.datetime.now(tz=datetime.UTC).date().year}"
+copyright = (  # noqa: A001
     f"{CREATION_YEAR}{('-' + CURRENT_YEAR) if CURRENT_YEAR != CREATION_YEAR else ''}, "
-    + f"{author} and AUTHORS"
+    f"{author} and AUTHORS"
 )
 RSTCHECK_VERSION = metadata(project)["Version"]
 release = RSTCHECK_VERSION  #: The full version, including alpha/beta/rc tags
@@ -44,9 +43,9 @@ RELEASE_LEVEL = None if not version_parts else version_parts.group("tag")
 
 
 #: -- GENERAL CONFIG -------------------------------------------------------------------
-extensions: t.List[str] = []
+extensions: list[str] = []
 today_fmt = "%Y-%m-%d"
-exclude_patterns: t.List[str] = []  #: Files to exclude for source of doc
+exclude_patterns: list[str] = []  #: Files to exclude for source of doc
 
 #: Added dirs for static and template files if they exist
 html_static_path = ["_static"] if Path("_static").exists() else []
@@ -71,9 +70,13 @@ rst_epilog = """
 tls_cacerts = os.getenv("SSL_CERT_FILE")
 
 
-#: -- M2R2 -----------------------------------------------------------------------------
-extensions.append("m2r2")
-source_suffix = [".rst", ".md"]
+#: -- MyST -----------------------------------------------------------------------------
+extensions.append("myst_parser")
+source_suffix = {
+    ".rst": "restructuredtext",
+    ".txt": "markdown",
+    ".md": "markdown",
+}
 
 
 #: -- LINKCHECK CONFIG -----------------------------------------------------------------
@@ -120,10 +123,10 @@ extensions.append("sphinx_click.ext")
 
 
 #: -- SPELLING -------------------------------------------------------------------------
-spelling_word_list_filename = "spelling_dict.txt"
+spelling_word_list_filename = "../../spelling_dict.txt"
 spelling_show_suggestions = True
 
-if find_spec("sphinxcontrib.spelling") is not None:
+if find_spec("sphinxcontrib.spelling") is not None and os.environ.get("SPHINX_SPELLING") == "true":
     extensions.append("sphinxcontrib.spelling")
 else:
     NOT_LOADED_MSGS.append("## 'sphinxcontrib-spelling' extension not loaded - not installed")
@@ -136,9 +139,6 @@ html_theme = "sphinx_rtd_theme"
 html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
 html_theme_options = {"style_external_links": True, "navigation_depth": 5}
 
-extensions.append("sphinx_rtd_dark_mode")
-default_dark_mode = False
-
 
 #: -- HTML OUTPUT ----------------------------------------------------------------------
 html_last_updated_fmt = today_fmt
@@ -152,4 +152,4 @@ def setup(app: Sphinx) -> None:
 
 
 for msg in NOT_LOADED_MSGS:
-    print(msg)
+    print(msg)  # noqa: T201
